@@ -22,6 +22,7 @@
 
 #include "htmlexport.h"
 #include "htmlexportsettings.h"
+#include "incidenceformatter.h"
 #include "calendar.h"
 #include "event.h"
 #include "todo.h"
@@ -95,28 +96,27 @@ bool HtmlExport::save( QTextStream *ts )
     return false;
   }
   ts->setCodec( "UTF-8" );
-
   // Write HTML header
   *ts << "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" ";
-  *ts << "\"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\n";
+  *ts << "\"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">"<<endl;
 
   *ts << "<html><head>" << endl;
   *ts << "  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=";
-  *ts << "UTF-8\" />\n";
+  *ts << "UTF-8\" />"<<endl;
   if ( !d->mSettings->pageTitle().isEmpty() ) {
-    *ts << "  <title>" << d->mSettings->pageTitle() << "</title>\n";
+    *ts << "  <title>" << d->mSettings->pageTitle() << "</title>"<<endl;
   }
-  *ts << "  <style type=\"text/css\">\n";
+  *ts << "  <style type=\"text/css\">"<<endl;
   *ts << styleSheet();
-  *ts << "  </style>\n";
-  *ts << "</head><body>\n";
+  *ts << "  </style>"<<endl;
+  *ts << "</head><body>"<<endl;
 
   // FIXME: Write header
   // (Heading, Calendar-Owner, Calendar-Date, ...)
 
   if ( d->mSettings->eventView() || d->mSettings->monthView() || d->mSettings->weekView() ) {
     if ( !d->mSettings->eventTitle().isEmpty() ) {
-      *ts << "<h1>" << d->mSettings->eventTitle() << "</h1>\n";
+      *ts << "<h1>" << d->mSettings->eventTitle() << "</h1>"<<endl;
     }
 
     // Write Week View
@@ -136,7 +136,7 @@ bool HtmlExport::save( QTextStream *ts )
   // Write Todo List
   if ( d->mSettings->todoView() ) {
     if ( !d->mSettings->todoListTitle().isEmpty() ) {
-      *ts << "<h1>" << d->mSettings->todoListTitle() << "</h1>\n";
+      *ts << "<h1>" << d->mSettings->todoListTitle() << "</h1>"<<endl;
     }
     createTodoList( ts );
   }
@@ -144,7 +144,7 @@ bool HtmlExport::save( QTextStream *ts )
   // Write Journals
   if ( d->mSettings->journalView() ) {
     if ( !d->mSettings->journalTitle().isEmpty() ) {
-      *ts << "<h1>" << d->mSettings->journalTitle() << "</h1>\n";
+      *ts << "<h1>" << d->mSettings->journalTitle() << "</h1>"<<endl;
     }
     createJournalView( ts );
   }
@@ -152,7 +152,7 @@ bool HtmlExport::save( QTextStream *ts )
   // Write Free/Busy
   if ( d->mSettings->freeBusyView() ) {
     if ( !d->mSettings->freeBusyTitle().isEmpty() ) {
-      *ts << "<h1>" << d->mSettings->freeBusyTitle() << "</h1>\n";
+      *ts << "<h1>" << d->mSettings->freeBusyTitle() << "</h1>"<<endl;
     }
     createFreeBusyView( ts );
   }
@@ -160,7 +160,7 @@ bool HtmlExport::save( QTextStream *ts )
   createFooter( ts );
 
   // Write HTML trailer
-  *ts << "</body></html>\n";
+  *ts << "</body></html>"<<endl;
 
   return true;
 }
@@ -177,10 +177,12 @@ void HtmlExport::createMonthView( QTextStream *ts )
 
   while ( start < toDate() ) {
     // Write header
+    QDate hDate( start.year(), start.month(), 1 );
+    QString hMon = hDate.toString( "MMMM" );
+    QString hYear = hDate.toString( "yyyy" );
     *ts << "<h2>"
-        << i18nc( "@title month and year", "%1 %2",
-                  KGlobal::locale()->calendar()->monthName( start ), start.year() )
-        << "</h2>\n";
+        << i18nc( "@title month and year", "%1 %2", hMon, hYear )
+        << "</h2>"<<endl;
     if ( KGlobal::locale()->weekStartDay() == 1 ) {
       start = start.addDays( 1 - start.dayOfWeek() );
     } else {
@@ -188,18 +190,18 @@ void HtmlExport::createMonthView( QTextStream *ts )
         start = start.addDays( -start.dayOfWeek() );
       }
     }
-    *ts << "<table border=\"1\">\n";
+    *ts << "<table border=\"1\">"<<endl;
 
     // Write table header
     *ts << "  <tr>";
     for ( int i=0; i < 7; ++i ) {
       *ts << "<th>" << KGlobal::locale()->calendar()->weekDayName( start.addDays(i) ) << "</th>";
     }
-    *ts << "</tr>\n";
+    *ts << "</tr>"<<endl;
 
     // Write days
     while ( start <= end ) {
-      *ts << "  <tr>\n";
+      *ts << "  <tr>"<<endl;
       for ( int i=0; i < 7; ++i ) {
         *ts << "    <td valign=\"top\"><table border=\"0\">";
 
@@ -223,7 +225,7 @@ void HtmlExport::createMonthView( QTextStream *ts )
         if ( events.count() ) {
           *ts << "<table>";
           Event::List::ConstIterator it;
-          for ( it = events.begin(); it != events.end(); ++it ) {
+          for ( it = events.constBegin(); it != events.constEnd(); ++it ) {
             if ( checkSecrecy( *it ) ) {
               createEvent( ts, *it, start, false );
             }
@@ -233,12 +235,12 @@ void HtmlExport::createMonthView( QTextStream *ts )
           *ts << "&nbsp;";
         }
 
-        *ts << "</td></tr></table></td>\n";
+        *ts << "</td></tr></table></td>"<<endl;
         start = start.addDays( 1 );
       }
-      *ts << "  </tr>\n";
+      *ts << "  </tr>"<<endl;
     }
-    *ts << "</table>\n";
+    *ts << "</table>"<<endl;
     startmonth += 1;
     if ( startmonth > 12 ) {
       startyear += 1;
@@ -252,31 +254,31 @@ void HtmlExport::createMonthView( QTextStream *ts )
 void HtmlExport::createEventList( QTextStream *ts )
 {
   int columns = 3;
-  *ts << "<table border=\"0\" cellpadding=\"3\" cellspacing=\"3\">\n";
-  *ts << "  <tr>\n";
+  *ts << "<table border=\"0\" cellpadding=\"3\" cellspacing=\"3\">"<<endl;
+  *ts << "  <tr>"<<endl;
   *ts << "    <th class=\"sum\">" << i18nc( "@title:column event start time",
-                                            "Start Time" ) << "</th>\n";
+                                            "Start Time" ) << "</th>"<<endl;
   *ts << "    <th>" << i18nc( "@title:column event end time",
-                              "End Time" ) << "</th>\n";
+                              "End Time" ) << "</th>"<<endl;
   *ts << "    <th>" << i18nc( "@title:column event description",
-                              "Event" ) << "</th>\n";
+                              "Event" ) << "</th>"<<endl;
   if ( d->mSettings->eventLocation() ) {
     *ts << "    <th>" << i18nc( "@title:column event locatin",
-                                "Location" ) << "</th>\n";
+                                "Location" ) << "</th>"<<endl;
     ++columns;
   }
   if ( d->mSettings->eventCategories() ) {
     *ts << "    <th>" << i18nc( "@title:column event categories",
-                                "Categories" ) << "</th>\n";
+                                "Categories" ) << "</th>"<<endl;
     ++columns;
   }
   if ( d->mSettings->eventAttendees() ) {
     *ts << "    <th>" << i18nc( "@title:column event attendees",
-                                "Attendees" ) << "</th>\n";
+                                "Attendees" ) << "</th>"<<endl;
     ++columns;
   }
 
-  *ts << "  </tr>\n";
+  *ts << "  </tr>"<<endl;
 
   for ( QDate dt = fromDate(); dt <= toDate(); dt = dt.addDays(1) ) {
     kDebug() << "Getting events for" << dt.toString();
@@ -287,10 +289,10 @@ void HtmlExport::createEventList( QTextStream *ts )
       *ts << "  <tr><td colspan=\"" << QString::number( columns )
           << "\" class=\"datehead\"><i>"
           << KGlobal::locale()->formatDate( dt )
-          << "</i></td></tr>\n";
+          << "</i></td></tr>"<<endl;
 
       Event::List::ConstIterator it;
-      for ( it = events.begin(); it != events.end(); ++it ) {
+      for ( it = events.constBegin(); it != events.constEnd(); ++it ) {
         if ( checkSecrecy( *it ) ) {
           createEvent( ts, *it, dt );
         }
@@ -298,58 +300,60 @@ void HtmlExport::createEventList( QTextStream *ts )
     }
   }
 
-  *ts << "</table>\n";
+  *ts << "</table>"<<endl;
 }
 
 void HtmlExport::createEvent ( QTextStream *ts, Event *event,
                                QDate date, bool withDescription )
 {
   kDebug() << event->summary();
-  *ts << "  <tr>\n";
+  *ts << "  <tr>"<<endl;
 
   if ( !event->allDay() ) {
     if ( event->isMultiDay( d->mCalendar->timeSpec() ) && ( event->dtStart().date() != date ) ) {
-      *ts << "    <td>&nbsp;</td>\n";
+      *ts << "    <td>&nbsp;</td>"<<endl;
     } else {
       *ts << "    <td valign=\"top\">"
-          << event->dtStartTimeStr( true, d->mCalendar->timeSpec() ) << "</td>\n";
+          << IncidenceFormatter::timeToString( event->dtStart(), true, d->mCalendar->timeSpec() )
+          << "</td>"<<endl;
     }
     if ( event->isMultiDay( d->mCalendar->timeSpec() ) && ( event->dtEnd().date() != date ) ) {
-      *ts << "    <td>&nbsp;</td>\n";
+      *ts << "    <td>&nbsp;</td>"<<endl;
     } else {
       *ts << "    <td valign=\"top\">"
-          << event->dtEndTimeStr( true, d->mCalendar->timeSpec() ) << "</td>\n";
+          << IncidenceFormatter::timeToString( event->dtEnd(), true, d->mCalendar->timeSpec() )
+          << "</td>"<<endl;
     }
   } else {
-    *ts << "    <td>&nbsp;</td><td>&nbsp;</td>\n";
+    *ts << "    <td>&nbsp;</td><td>&nbsp;</td>"<<endl;
   }
 
-  *ts << "    <td class=\"sum\">\n";
-  *ts << "      <b>" << cleanChars( event->summary() ) << "</b>\n";
+  *ts << "    <td class=\"sum\">"<<endl;
+  *ts << "      <b>" << cleanChars( event->summary() ) << "</b>"<<endl;
   if ( withDescription && !event->description().isEmpty() ) {
-    *ts << "      <p>" << breakString( cleanChars( event->description() ) ) << "</p>\n";
+    *ts << "      <p>" << breakString( cleanChars( event->description() ) ) << "</p>"<<endl;
   }
-  *ts << "    </td>\n";
+  *ts << "    </td>"<<endl;
 
   if ( d->mSettings->eventLocation() ) {
-    *ts << "  <td>\n";
+    *ts << "  <td>"<<endl;
     formatLocation( ts, event );
-    *ts << "  </td>\n";
+    *ts << "  </td>"<<endl;
   }
 
   if ( d->mSettings->eventCategories() ) {
-    *ts << "  <td>\n";
+    *ts << "  <td>"<<endl;
     formatCategories( ts, event );
-    *ts << "  </td>\n";
+    *ts << "  </td>"<<endl;
   }
 
   if ( d->mSettings->eventAttendees() ) {
-    *ts << "  <td>\n";
+    *ts << "  <td>"<<endl;
     formatAttendees( ts, event );
-    *ts << "  </td>\n";
+    *ts << "  </td>"<<endl;
   }
 
-  *ts << "  </tr>\n";
+  *ts << "  </tr>"<<endl;
 }
 
 void HtmlExport::createTodoList ( QTextStream *ts )
@@ -376,70 +380,70 @@ void HtmlExport::createTodoList ( QTextStream *ts )
   Todo::List todoList;
   Todo::List::ConstIterator it;
   for ( int i = 1; i <= 9; ++i ) {
-    for ( it = rawTodoList.begin(); it != rawTodoList.end(); ++it ) {
+    for ( it = rawTodoList.constBegin(); it != rawTodoList.constEnd(); ++it ) {
       if ( (*it)->priority() == i && checkSecrecy( *it ) ) {
         todoList.append( *it );
       }
     }
   }
-  for ( it = rawTodoList.begin(); it != rawTodoList.end(); ++it ) {
+  for ( it = rawTodoList.constBegin(); it != rawTodoList.constEnd(); ++it ) {
     if ( (*it)->priority() == 0 && checkSecrecy( *it ) ) {
       todoList.append( *it );
     }
   }
 
   int columns = 3;
-  *ts << "<table border=\"0\" cellpadding=\"3\" cellspacing=\"3\">\n";
-  *ts << "  <tr>\n";
-  *ts << "    <th class=\"sum\">" << i18nc( "@title:column", "To-do" ) << "</th>\n";
-  *ts << "    <th>" << i18nc( "@title:column to-do priority", "Priority" ) << "</th>\n";
-  *ts << "    <th>" << i18nc( "@title:column to-do percent completed", "Completed" ) << "</th>\n";
+  *ts << "<table border=\"0\" cellpadding=\"3\" cellspacing=\"3\">"<<endl;
+  *ts << "  <tr>"<<endl;
+  *ts << "    <th class=\"sum\">" << i18nc( "@title:column", "To-do" ) << "</th>"<<endl;
+  *ts << "    <th>" << i18nc( "@title:column to-do priority", "Priority" ) << "</th>"<<endl;
+  *ts << "    <th>" << i18nc( "@title:column to-do percent completed", "Completed" ) << "</th>"<<endl;
   if ( d->mSettings->taskDueDate() ) {
-    *ts << "    <th>" << i18nc( "@title:column to-do due date", "Due Date" ) << "</th>\n";
+    *ts << "    <th>" << i18nc( "@title:column to-do due date", "Due Date" ) << "</th>"<<endl;
     ++columns;
   }
   if ( d->mSettings->taskLocation() ) {
-    *ts << "    <th>" << i18nc( "@title:column to-do location", "Location" ) << "</th>\n";
+    *ts << "    <th>" << i18nc( "@title:column to-do location", "Location" ) << "</th>"<<endl;
     ++columns;
   }
   if ( d->mSettings->taskCategories() ) {
-    *ts << "    <th>" << i18nc( "@title:column to-do categories", "Categories" ) << "</th>\n";
+    *ts << "    <th>" << i18nc( "@title:column to-do categories", "Categories" ) << "</th>"<<endl;
     ++columns;
   }
   if ( d->mSettings->taskAttendees() ) {
-    *ts << "    <th>" << i18nc( "@title:column to-do attendees", "Attendees" ) << "</th>\n";
+    *ts << "    <th>" << i18nc( "@title:column to-do attendees", "Attendees" ) << "</th>"<<endl;
     ++columns;
   }
-  *ts << "  </tr>\n";
+  *ts << "  </tr>"<<endl;
 
   // Create top-level list.
-  for ( it = todoList.begin(); it != todoList.end(); ++it ) {
+  for ( it = todoList.constBegin(); it != todoList.constEnd(); ++it ) {
     if ( !(*it)->relatedTo() ) {
       createTodo( ts, *it );
     }
   }
 
   // Create sub-level lists
-  for ( it = todoList.begin(); it != todoList.end(); ++it ) {
+  for ( it = todoList.constBegin(); it != todoList.constEnd(); ++it ) {
     Incidence::List relations = (*it)->relations();
     if ( relations.count() ) {
       // Generate sub-to-do list
-      *ts << "  <tr>\n";
+      *ts << "  <tr>"<<endl;
       *ts << "    <td class=\"subhead\" colspan=";
       *ts << "\"" << QString::number(columns) << "\"";
       *ts << "><a name=\"sub" << (*it)->uid() << "\"></a>"
           << i18nc( "@title:column sub-to-dos of the parent to-do",
                     "Sub-To-dos of: " ) << "<a href=\"#"
           << (*it)->uid() << "\"><b>" << cleanChars( (*it)->summary() )
-          << "</b></a></td>\n";
-      *ts << "  </tr>\n";
+          << "</b></a></td>"<<endl;
+      *ts << "  </tr>"<<endl;
 
       Todo::List sortedList;
       // FIXME: Sort list by priorities. This is brute force and should be
       // replaced by a real sorting algorithm.
       for ( int i = 1; i <= 9; ++i ) {
         Incidence::List::ConstIterator it2;
-        for ( it2 = relations.begin(); it2 != relations.end(); ++it2 ) {
+        for ( it2 = relations.constBegin(); it2 != relations.constEnd(); ++it2 ) {
           Todo *ev3 = dynamic_cast<Todo *>( *it2 );
           if ( ev3 && ev3->priority() == i ) {
             sortedList.append( ev3 );
@@ -447,7 +451,7 @@ void HtmlExport::createTodoList ( QTextStream *ts )
         }
       }
       Incidence::List::ConstIterator it2;
-      for ( it2 = relations.begin(); it2 != relations.end(); ++it2 ) {
+      for ( it2 = relations.constBegin(); it2 != relations.constEnd(); ++it2 ) {
         Todo *ev3 = dynamic_cast<Todo *>( *it2 );
         if ( ev3 && ev3->priority() == 0 ) {
           sortedList.append( ev3 );
@@ -455,13 +459,13 @@ void HtmlExport::createTodoList ( QTextStream *ts )
       }
 
       Todo::List::ConstIterator it3;
-      for ( it3 = sortedList.begin(); it3 != sortedList.end(); ++it3 ) {
+      for ( it3 = sortedList.constBegin(); it3 != sortedList.constEnd(); ++it3 ) {
         createTodo( ts, *it3 );
       }
     }
   }
 
-  *ts << "</table>\n";
+  *ts << "</table>"<<endl;
 }
 
 void HtmlExport::createTodo( QTextStream *ts, Todo *todo )
@@ -471,52 +475,52 @@ void HtmlExport::createTodo( QTextStream *ts, Todo *todo )
   bool completed = todo->isCompleted();
   Incidence::List relations = todo->relations();
 
-  *ts << "<tr>\n";
+  *ts << "<tr>"<<endl;
 
   *ts << "  <td class=\"sum";
   if (completed) *ts << "done";
-  *ts << "\">\n";
-  *ts << "    <a name=\"" << todo->uid() << "\"></a>\n";
-  *ts << "    <b>" << cleanChars( todo->summary() ) << "</b>\n";
+  *ts << "\">"<<endl;
+  *ts << "    <a name=\"" << todo->uid() << "\"></a>"<<endl;
+  *ts << "    <b>" << cleanChars( todo->summary() ) << "</b>"<<endl;
   if ( !todo->description().isEmpty() ) {
-    *ts << "    <p>" << breakString( cleanChars( todo->description() ) ) << "</p>\n";
+    *ts << "    <p>" << breakString( cleanChars( todo->description() ) ) << "</p>"<<endl;
   }
   if ( relations.count() ) {
     *ts << "    <div align=\"right\"><a href=\"#sub" << todo->uid()
         << "\">" << i18nc( "@title:column sub-to-dos of the parent to-do",
-                           "Sub-To-dos" ) << "</a></div>\n";
+                           "Sub-To-dos" ) << "</a></div>"<<endl;
   }
-  *ts << "  </td>\n";
+  *ts << "  </td>"<<endl;
 
   *ts << "  <td";
   if ( completed ) {
     *ts << " class=\"done\"";
   }
-  *ts << ">\n";
-  *ts << "    " << todo->priority() << "\n";
-  *ts << "  </td>\n";
+  *ts << ">"<<endl;
+  *ts << "    " << todo->priority() <<endl;
+  *ts << "  </td>"<<endl;
 
   *ts << "  <td";
   if ( completed ) {
     *ts << " class=\"done\"";
   }
-  *ts << ">\n";
-  *ts << "    " << i18nc( "@info to-do percent complete",
-                          "%1 %", todo->percentComplete() ) << "\n";
-  *ts << "  </td>\n";
+  *ts << ">"<<endl;
+  *ts << "    " << i18nc( "@info/plain to-do percent complete",
+                          "%1 %", todo->percentComplete() ) <<endl;
+  *ts << "  </td>"<<endl;
 
   if ( d->mSettings->taskDueDate() ) {
     *ts << "  <td";
     if ( completed ) {
       *ts << " class=\"done\"";
     }
-    *ts << ">\n";
+    *ts << ">"<<endl;
     if ( todo->hasDueDate() ) {
-      *ts << "    " << todo->dtDueDateStr() << "\n";
+      *ts << "    " << IncidenceFormatter::dateToString(todo->dtDue(true)) <<endl;
     } else {
-      *ts << "    &nbsp;\n";
+      *ts << "    &nbsp;"<<endl;
     }
-    *ts << "  </td>\n";
+    *ts << "  </td>"<<endl;
   }
 
   if ( d->mSettings->taskLocation() ) {
@@ -524,9 +528,9 @@ void HtmlExport::createTodo( QTextStream *ts, Todo *todo )
     if ( completed ) {
       *ts << " class=\"done\"";
     }
-    *ts << ">\n";
+    *ts << ">"<<endl;
     formatLocation( ts, todo );
-    *ts << "  </td>\n";
+    *ts << "  </td>"<<endl;
   }
 
   if ( d->mSettings->taskCategories() ) {
@@ -534,9 +538,9 @@ void HtmlExport::createTodo( QTextStream *ts, Todo *todo )
     if ( completed ) {
       *ts << " class=\"done\"";
     }
-    *ts << ">\n";
+    *ts << ">"<<endl;
     formatCategories( ts, todo );
-    *ts << "  </td>\n";
+    *ts << "  </td>"<<endl;
   }
 
   if ( d->mSettings->taskAttendees() ) {
@@ -544,12 +548,12 @@ void HtmlExport::createTodo( QTextStream *ts, Todo *todo )
     if ( completed ) {
       *ts << " class=\"done\"";
     }
-    *ts << ">\n";
+    *ts << ">"<<endl;
     formatAttendees( ts, todo );
-    *ts << "  </td>\n";
+    *ts << "  </td>"<<endl;
   }
 
-  *ts << "</tr>\n";
+  *ts << "</tr>"<<endl;
 }
 
 void HtmlExport::createWeekView( QTextStream *ts )
@@ -590,18 +594,18 @@ bool HtmlExport::checkSecrecy( Incidence *incidence )
 void HtmlExport::formatLocation( QTextStream *ts, Incidence *incidence )
 {
   if ( !incidence->location().isEmpty() ) {
-    *ts << "    " << cleanChars( incidence->location() ) << "\n";
+    *ts << "    " << cleanChars( incidence->location() ) <<endl;
   } else {
-    *ts << "    &nbsp;\n";
+    *ts << "    &nbsp;"<<endl;
   }
 }
 
 void HtmlExport::formatCategories( QTextStream *ts, Incidence *incidence )
 {
   if ( !incidence->categoriesStr().isEmpty() ) {
-    *ts << "    " << cleanChars( incidence->categoriesStr() ) << "\n";
+    *ts << "    " << cleanChars( incidence->categoriesStr() ) <<endl;
   } else {
-    *ts << "    &nbsp;\n";
+    *ts << "    &nbsp;"<<endl;
   }
 }
 
@@ -614,19 +618,21 @@ void HtmlExport::formatAttendees( QTextStream *ts, Incidence *incidence )
     KABC::AddressBook *add_book = KABC::StdAddressBook::self( true );
     KABC::Addressee::List addressList;
     addressList = add_book->findByEmail( incidence->organizer().email() );
-    KABC::Addressee o = addressList.first();
-    if ( !o.isEmpty() && addressList.size() < 2 ) {
-      *ts << "<a href=\"mailto:" << incidence->organizer().email() << "\">";
-      *ts << cleanChars( o.formattedName() ) << "</a>\n";
-    } else {
-      *ts << incidence->organizer().fullName();
+    if ( !addressList.isEmpty() ) {
+      KABC::Addressee o = addressList.first();
+      if ( !o.isEmpty() && addressList.size() < 2 ) {
+        *ts << "<a href=\"mailto:" << incidence->organizer().email() << "\">";
+        *ts << cleanChars( o.formattedName() ) << "</a>"<<endl;
+      } else {
+        *ts << incidence->organizer().fullName();
+      }
     }
 #else
     *ts << incidence->organizer().fullName();
 #endif
     *ts << "</em><br />";
     Attendee::List::ConstIterator it;
-    for ( it = attendees.begin(); it != attendees.end(); ++it ) {
+    for ( it = attendees.constBegin(); it != attendees.constEnd(); ++it ) {
       Attendee *a = *it;
       if ( !a->email().isEmpty() ) {
         *ts << "<a href=\"mailto:" << a->email();
@@ -634,10 +640,10 @@ void HtmlExport::formatAttendees( QTextStream *ts, Incidence *incidence )
       } else {
         *ts << "    " << cleanChars( a->name() );
       }
-      *ts << "<br />" << "\n";
+      *ts << "<br />" <<endl;
     }
   } else {
-    *ts << "    &nbsp;\n";
+    *ts << "    &nbsp;"<<endl;
   }
 }
 
@@ -651,7 +657,7 @@ QString HtmlExport::breakString( const QString &text )
     QString tmpText = text;
     int pos = 0;
     QString tmp;
-    for ( int i=0; i<=number; i++ ) {
+    for ( int i = 0; i <= number; ++i ) {
       pos = tmpText.indexOf( "\n" );
       tmp = tmpText.left( pos );
       tmpText = tmpText.right( tmpText.length() - pos - 1 );
@@ -664,7 +670,7 @@ QString HtmlExport::breakString( const QString &text )
 void HtmlExport::createFooter( QTextStream *ts )
 {
   // FIXME: Implement this in a translatable way!
-  QString trailer = i18nc( "@info", "This page was created " );
+  QString trailer = i18nc( "@info/plain", "This page was created " );
 
 /*  bool hasPerson = false;
   bool hasCredit = false;
@@ -672,40 +678,40 @@ void HtmlExport::createFooter( QTextStream *ts )
   QString mail, name, credit, creditURL;*/
   if ( !d->mSettings->eMail().isEmpty() ) {
     if ( !d->mSettings->name().isEmpty() ) {
-      trailer += i18nc( "@info page creator email link with name",
+      trailer += i18nc( "@info/plain page creator email link with name",
                         "by <link url='mailto:%1'>%2</link>",
                         d->mSettings->eMail(), d->mSettings->name() );
     } else {
-      trailer += i18nc( "@info page creator email link",
+      trailer += i18nc( "@info/plain page creator email link",
                         "by <link url='mailto:%1'>%2</link>",
                         d->mSettings->eMail(), d->mSettings->eMail() );
     }
   } else {
     if ( !d->mSettings->name().isEmpty() ) {
-      trailer += i18nc( "@info page creator name only",
+      trailer += i18nc( "@info/plain page creator name only",
                         "by %1 ", d->mSettings->name() );
     }
   }
   if ( !d->mSettings->creditName().isEmpty() ) {
     if ( !d->mSettings->creditURL().isEmpty() ) {
-      trailer += i18nc( "@info page credit with name and link",
+      trailer += i18nc( "@info/plain page credit with name and link",
                         "with <link url='%1'>%2</link>",
                         d->mSettings->creditURL(), d->mSettings->creditName() );
     } else {
-      trailer += i18nc( "@info page credit name only",
+      trailer += i18nc( "@info/plain page credit name only",
                         "with %1", d->mSettings->creditName() );
     }
   }
-  *ts << "<p>" << trailer << "</p>\n";
+  *ts << "<p>" << trailer << "</p>"<<endl;
 }
 
 QString cleanChars( const QString &text )
 {
   QString txt = text;
-  txt = txt.replace( "&", "&amp;" );
-  txt = txt.replace( "<", "&lt;" );
-  txt = txt.replace( ">", "&gt;" );
-  txt = txt.replace( "\"", "&quot;" );
+  txt = txt.replace( '&', "&amp;" );
+  txt = txt.replace( '<', "&lt;" );
+  txt = txt.replace( '>', "&gt;" );
+  txt = txt.replace( '\"', "&quot;" );
   txt = txt.replace( QString::fromUtf8( "ä" ), "&auml;" );
   txt = txt.replace( QString::fromUtf8( "Ä" ), "&Auml;" );
   txt = txt.replace( QString::fromUtf8( "ö" ), "&ouml;" );
@@ -759,7 +765,7 @@ void HtmlExport::addHoliday( const QDate &date, const QString &name )
   if ( d->mHolidayMap[date].isEmpty() ) {
     d->mHolidayMap[date] = name;
   } else {
-    d->mHolidayMap[date] = i18nc( "@info holiday by date and name",
+    d->mHolidayMap[date] = i18nc( "@info/plain holiday by date and name",
                                   "%1, %2", d->mHolidayMap[date], name );
   }
 }
