@@ -78,8 +78,9 @@ static QString quoteForParam( const QString &text )
 {
   QString tmp = text;
   tmp.remove( '"' );
-  if ( tmp.contains( ';' ) || tmp.contains( ':' ) || tmp.contains( ',' ) )
+  if ( tmp.contains( ';' ) || tmp.contains( ':' ) || tmp.contains( ',' ) ) {
     return tmp; // libical quotes in this case already, see icalparameter_as_ical_string()
+  }
   return QString::fromLatin1( "\"" ) + tmp + QString::fromLatin1( "\"" );
 }
 
@@ -202,7 +203,7 @@ icalcomponent *ICalFormatImpl::writeTodo( Todo *todo, ICalTimeZones *tzlist,
   }
 
   // start time
-  if ( todo->hasStartDate() || todo->recurs() ) {
+  if ( todo->hasStartDate() ) {
     icaltimetype start;
     if ( todo->allDay() ) {
       start = writeICalDate( todo->dtStart( true ).date() );
@@ -487,6 +488,14 @@ void ICalFormatImpl::writeIncidence( icalcomponent *parent,
     icalcomponent_add_property( parent, icalproperty_new_class( secClass ) );
   }
 
+  // geo
+  if ( incidence->hasGeo() ) {
+    icalgeotype geo;
+    geo.lat = incidence->geoLatitude();
+    geo.lon = incidence->geoLongitude();
+    icalcomponent_add_property( parent, icalproperty_new_geo( geo ) );
+  }
+
   // priority
   if ( incidence->priority() > 0 ) { // 0 is undefined priority
     icalcomponent_add_property(
@@ -518,7 +527,7 @@ void ICalFormatImpl::writeIncidence( icalcomponent *parent,
   RecurrenceRule::List::ConstIterator exit;
   for ( exit = exrules.constBegin(); exit != exrules.constEnd(); ++exit ) {
     icalcomponent_add_property(
-      parent, icalproperty_new_rrule( writeRecurrenceRule( (*exit) ) ) );
+      parent, icalproperty_new_exrule( writeRecurrenceRule( (*exit) ) ) );
   }
 
   DateList dateList = incidence->recurrence()->exDates();
@@ -1250,7 +1259,7 @@ Attendee *ICalFormatImpl::readAttendee( icalproperty *attendee )
   icalparameter *p = 0;
 
   QString email = QString::fromUtf8( icalproperty_get_attendee( attendee ) );
-  if ( email.startsWith( "mailto:", Qt::CaseInsensitive ) ) {
+  if ( email.startsWith( QLatin1String( "mailto:" ), Qt::CaseInsensitive ) ) {
     email = email.mid( 7 );
   }
 
@@ -1350,7 +1359,7 @@ Attendee *ICalFormatImpl::readAttendee( icalproperty *attendee )
 Person ICalFormatImpl::readOrganizer( icalproperty *organizer )
 {
   QString email = QString::fromUtf8( icalproperty_get_organizer( organizer ) );
-  if ( email.startsWith( "mailto:", Qt::CaseInsensitive ) ) {
+  if ( email.startsWith( QLatin1String( "mailto:" ), Qt::CaseInsensitive ) ) {
     email = email.mid( 7 );
   }
   QString cn;
@@ -1515,6 +1524,12 @@ void ICalFormatImpl::readIncidence( icalcomponent *parent,
 
     case ICAL_LOCATION_PROPERTY:  // location
     {
+      if ( !icalproperty_get_value( p ) ) {
+        //Fix for #191472. This is a pre-crash guard in case libical was
+        //compiled in superstrict mode (--enable-icalerrors-are-fatal)
+        //TODO: pre-crash guard other property getters too.
+        break;
+      }
       QString textStr = QString::fromUtf8( icalproperty_get_location( p ) );
       if ( !textStr.isEmpty() ) {
         QString valStr = QString::fromUtf8(
@@ -1572,6 +1587,15 @@ void ICalFormatImpl::readIncidence( icalcomponent *parent,
       break;
     }
 
+    case ICAL_GEO_PROPERTY:  // geo
+    {
+      icalgeotype geo = icalproperty_get_geo( p );
+      incidence->setGeoLatitude( geo.lat );
+      incidence->setGeoLongitude( geo.lon );
+      incidence->setHasGeo( true );
+      break;
+    }
+
     case ICAL_PRIORITY_PROPERTY:  // priority
       intvalue = icalproperty_get_priority( p );
       if ( d->mCompat ) {
@@ -1960,7 +1984,7 @@ void ICalFormatImpl::readAlarm( icalcomponent *alarm,
     case ICAL_ATTENDEE_PROPERTY:
     { // Only in EMAIL alarm
       QString email = QString::fromUtf8( icalproperty_get_attendee( p ) );
-      if ( email.startsWith( "mailto:", Qt::CaseInsensitive ) ) {
+      if ( email.startsWith( QLatin1String( "mailto:" ), Qt::CaseInsensitive ) ) {
         email = email.mid( 7 );
       }
       QString name;
@@ -2247,6 +2271,10 @@ KDateTime ICalFormatImpl::readICalDateTimeProperty( icalproperty *p,
 
 icaldurationtype ICalFormatImpl::writeICalDuration( const Duration &duration )
 {
+  // should be able to use icaldurationtype_from_int(), except we know
+  // that some older tools do not properly support weeks. So we never
+  // set a week duration, only days
+
   icaldurationtype d;
 
   int value = duration.value();
@@ -2254,31 +2282,20 @@ icaldurationtype ICalFormatImpl::writeICalDuration( const Duration &duration )
   if ( value < 0 ) {
     value = -value;
   }
-  // RFC2445 states that an ical duration value must be
-  // EITHER weeks OR days/time, not both.
+
   if ( duration.isDaily() ) {
-    if ( !( value % 7 ) ) {
-      d.weeks = value / 7;
-      d.days  = 0;
-    } else {
-      d.weeks = 0;
-      d.days  = value;
-    }
+    d.weeks = 0;
+    d.days  = value;
     d.hours = d.minutes = d.seconds = 0;
   } else {
-    if ( !( value % gSecondsPerWeek ) ) {
-      d.weeks = value / gSecondsPerWeek;
-      d.days = d.hours = d.minutes = d.seconds = 0;
-    } else {
-      d.weeks   = 0;
-      d.days    = value / gSecondsPerDay;
-      value    %= gSecondsPerDay;
-      d.hours   = value / gSecondsPerHour;
-      value    %= gSecondsPerHour;
-      d.minutes = value / gSecondsPerMinute;
-      value    %= gSecondsPerMinute;
-      d.seconds = value;
-    }
+    d.weeks   = 0;
+    d.days    = value / gSecondsPerDay;
+    value    %= gSecondsPerDay;
+    d.hours   = value / gSecondsPerHour;
+    value    %= gSecondsPerHour;
+    d.minutes = value / gSecondsPerMinute;
+    value    %= gSecondsPerMinute;
+    d.seconds = value;
   }
 
   return d;
@@ -2318,12 +2335,26 @@ icalcomponent *ICalFormatImpl::createCalendarComponent( Calendar *cal )
   p = icalproperty_new_prodid( CalFormat::productId().toUtf8() );
   icalcomponent_add_property( calendar, p );
 
-  // TODO: Add time zone
-
   // iCalendar version (2.0)
   p = icalproperty_new_version( const_cast<char *>(_ICAL_VERSION) );
   icalcomponent_add_property( calendar, p );
 
+  // Add time zone
+  if ( cal && cal->timeZones() ) {
+    const ICalTimeZones::ZoneMap zmaps = cal->timeZones()->zones();
+    for ( ICalTimeZones::ZoneMap::ConstIterator it=zmaps.constBegin();
+          it != zmaps.constEnd(); ++it ) {
+      icaltimezone *icaltz = (*it).icalTimezone();
+      if ( !icaltz ) {
+        kError() << "bad time zone";
+      } else {
+        icalcomponent *tz = icalcomponent_new_clone( icaltimezone_get_component( icaltz ) );
+        icalcomponent_add_component( calendar, tz );
+        icaltimezone_free( icaltz, 1 );
+      }
+    }
+  }
+
   // Custom properties
   if( cal != 0 ) {
     d->writeCustomProperties( calendar, cal );
@@ -2366,7 +2397,12 @@ bool ICalFormatImpl::populate( Calendar *cal, icalcomponent *calendar )
     return false;
   } else {
     const char *version = icalproperty_get_version( p );
-
+    if ( !version ) {
+      kDebug() << "No VERSION property found";
+      d->mParent->setException( new ErrorFormat(
+                                  ErrorFormat::CalVersionUnknown ) );
+      return false;
+    }
     if ( strcmp( version, "1.0" ) == 0 ) {
       kDebug() << "Expected iCalendar, got vCalendar";
       d->mParent->setException(
@@ -2524,6 +2560,51 @@ icalcomponent *ICalFormatImpl::createScheduleComponent( IncidenceBase *incidence
 {
   icalcomponent *message = createCalendarComponent();
 
+  // Create VTIMEZONE components for this incidence
+  ICalTimeZones zones;
+  if ( incidence ) {
+    if ( incidence->type() == "Event" ) {
+      Event *ev = static_cast<Event *>( incidence );
+      if ( ev ) {
+        if ( ev->dtStart().isValid() ) {
+          zones.add( ICalTimeZone( ev->dtStart().timeZone() ) );
+        }
+        if ( ev->hasEndDate() && ev->dtEnd().isValid() ) {
+          zones.add( ICalTimeZone( ev->dtEnd().timeZone() ) );
+        }
+      }
+    } else if ( incidence->type() == "Todo" ) {
+      Todo *t = static_cast<Todo *>( incidence );
+      if ( t ) {
+        if ( t->hasStartDate() && t->dtStart().isValid() ) {
+          zones.add( ICalTimeZone( t->dtStart( true ).timeZone() ) );
+        }
+        if ( t->hasDueDate() && t->dtDue().isValid() ) {
+          zones.add( ICalTimeZone( t->dtDue().timeZone() ) );
+        }
+      }
+    } else if ( incidence->type() == "Journal" ) {
+      Journal *j = static_cast<Journal *>( incidence );
+      if ( j ) {
+        if ( j->dtStart().isValid() ) {
+          zones.add( ICalTimeZone( j->dtStart().timeZone() ) );
+        }
+      }
+    }
+    const ICalTimeZones::ZoneMap zmaps = zones.zones();
+    for ( ICalTimeZones::ZoneMap::ConstIterator it=zmaps.constBegin();
+          it != zmaps.constEnd(); ++it ) {
+      icaltimezone *icaltz = (*it).icalTimezone();
+      if ( !icaltz ) {
+        kError() << "bad time zone";
+      } else {
+        icalcomponent *tz = icalcomponent_new_clone( icaltimezone_get_component( icaltz ) );
+        icalcomponent_add_component( message, tz );
+        icaltimezone_free( icaltz, 1 );
+      }
+    }
+  }
+
   icalproperty_method icalmethod = ICAL_METHOD_NONE;
 
   switch (method) {
