@@ -52,6 +52,7 @@
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kcalendarsystem.h>
+#include <ksystemtimezone.h>
 
 #include <QtCore/QBuffer>
 #include <QtCore/QList>
@@ -255,6 +256,10 @@ static QString eventViewerFormatHeader( Incidence *incidence )
   // show icons
   KIconLoader *iconLoader = KIconLoader::global();
   tmpStr += "<td>";
+
+  // TODO: KDE5. Make the function QString Incidence::getPixmap() so we don't
+  // need downcasting.
+
   if ( incidence->type() == "Todo" ) {
     tmpStr += "<img src=\"";
     Todo *todo = static_cast<Todo *>( incidence );
@@ -265,11 +270,19 @@ static QString eventViewerFormatHeader( Incidence *incidence )
     }
     tmpStr += "\">";
   }
+
   if ( incidence->type() == "Event" ) {
     tmpStr += "<img src=\"" +
               iconLoader->iconPath( "view-calendar-day", KIconLoader::Small ) +
               "\">";
   }
+
+  if ( incidence->type() == "Journal" ) {
+    tmpStr += "<img src=\"" +
+              iconLoader->iconPath( "view-pim-journal", KIconLoader::Small ) +
+              "\">";
+  }
+
   if ( incidence->isAlarmEnabled() ) {
     tmpStr += "<img src=\"" +
               iconLoader->iconPath( "preferences-desktop-notification-bell", KIconLoader::Small ) +
@@ -317,14 +330,14 @@ static QString eventViewerFormatEvent( Event *event, KDateTime::Spec spec )
       tmpStr += "<td align=\"right\"><b>" + i18n( "Time" ) + "</b></td>";
       tmpStr += "<td>" +
                 i18nc( "<beginTime> - <endTime>","%1 - %2",
-                       event->dtStartDateStr( true, spec ),
-                       event->dtEndDateStr( true, spec ) ) +
+                       IncidenceFormatter::dateToString( event->dtStart(), true, spec ),
+                       IncidenceFormatter::dateToString( event->dtEnd(), true, spec ) ) +
                 "</td>";
     } else {
       tmpStr += "<td align=\"right\"><b>" + i18n( "Date" ) + "</b></td>";
       tmpStr += "<td>" +
                 i18nc( "date as string","%1",
-                       event->dtStartDateStr( true, spec ) ) +
+                       IncidenceFormatter::dateToString( event->dtStart(), true, spec ) ) +
                 "</td>";
     }
   } else {
@@ -332,25 +345,27 @@ static QString eventViewerFormatEvent( Event *event, KDateTime::Spec spec )
       tmpStr += "<td align=\"right\"><b>" + i18n( "Time" ) + "</b></td>";
       tmpStr += "<td>" +
                 i18nc( "<beginTime> - <endTime>","%1 - %2",
-                       event->dtStartStr( true, spec ),
-                       event->dtEndStr( true, spec ) ) +
+                       IncidenceFormatter::dateToString( event->dtStart(), true, spec ),
+                       IncidenceFormatter::dateToString( event->dtEnd(), true, spec ) ) +
                 "</td>";
     } else {
       tmpStr += "<td align=\"right\"><b>" + i18n( "Time" ) + "</b></td>";
       if ( event->hasEndDate() && event->dtStart() != event->dtEnd() ) {
         tmpStr += "<td>" +
                   i18nc( "<beginTime> - <endTime>","%1 - %2",
-                         event->dtStartTimeStr( true, spec ),
-                         event->dtEndTimeStr( true, spec ) ) +
+                         IncidenceFormatter::timeToString( event->dtStart(), true, spec ),
+                         IncidenceFormatter::timeToString( event->dtEnd(), true, spec ) ) +
                   "</td>";
       } else {
-        tmpStr += "<td>" + event->dtStartTimeStr( true, spec ) + "</td>";
+        tmpStr += "<td>" +
+                  IncidenceFormatter::timeToString( event->dtStart(), true, spec ) +
+                  "</td>";
       }
       tmpStr += "</tr><tr>";
       tmpStr += "<td align=\"right\"><b>" + i18n( "Date" ) + "</b></td>";
       tmpStr += "<td>" +
                 i18nc( "date as string","%1",
-                       event->dtStartDateStr( true, spec ) ) +
+                       IncidenceFormatter::dateToString( event->dtStart(), true, spec ) ) +
                 "</td>";
     }
   }
@@ -386,7 +401,10 @@ static QString eventViewerFormatEvent( Event *event, KDateTime::Spec spec )
     tmpStr += "<tr>";
     tmpStr += "<td align=\"right\"><b>" + i18n( "Next Occurrence" )+ "</b></td>";
     tmpStr += "<td>" +
-              KGlobal::locale()->formatDateTime( dt.dateTime(), KLocale::ShortDate ) + "</td>";
+              ( dt.isValid() ?
+                KGlobal::locale()->formatDateTime( dt.dateTime(), KLocale::ShortDate ) :
+                i18nc( "no date", "none" ) ) +
+              "</td>";
     tmpStr += "</tr>";
   }
 
@@ -402,11 +420,12 @@ static QString eventViewerFormatEvent( Event *event, KDateTime::Spec spec )
     tmpStr += "<td>" + eventViewerFormatAttachments( event ) + "</td>";
     tmpStr += "</tr>";
   }
-
+  KDateTime kdt = event->created().toTimeSpec( spec );
   tmpStr += "</table>";
   tmpStr += "<p><em>" +
             i18n( "Creation date: %1", KGlobal::locale()->formatDateTime(
-                    event->created().dateTime(), KLocale::ShortDate ) ) + "</em>";
+                    kdt.dateTime(),
+                    KLocale::ShortDate ) ) + "</em>";
   return tmpStr;
 }
 
@@ -424,7 +443,10 @@ static QString eventViewerFormatTodo( Todo *todo, KDateTime::Spec spec )
   }
 
   if ( todo->hasDueDate() && todo->dtDue().isValid() ) {
-    tmpStr += i18n( "<b>Due on:</b> %1", todo->dtDueStr( true, spec ) );
+    tmpStr += i18n( "<b>Due on:</b> %1",
+                    IncidenceFormatter::dateTimeToString( todo->dtDue(),
+                                                          todo->allDay(),
+                                                          true, spec ) );
   }
 
   if ( !todo->description().isEmpty() ) {
@@ -449,8 +471,10 @@ static QString eventViewerFormatTodo( Todo *todo, KDateTime::Spec spec )
   }
   tmpStr += eventViewerFormatAttendees( todo );
   tmpStr += eventViewerFormatAttachments( todo );
+
+  KDateTime kdt = todo->created().toTimeSpec( spec );
   tmpStr += "<p><em>" + i18n( "Creation date: %1",
-    KGlobal::locale()->formatDateTime( todo->created().dateTime(), KLocale::ShortDate ) ) + "</em>";
+    KGlobal::locale()->formatDateTime( kdt.dateTime(), KLocale::ShortDate ) ) + "</em>";
   return tmpStr;
 }
 
@@ -460,12 +484,11 @@ static QString eventViewerFormatJournal( Journal *journal, KDateTime::Spec spec
     return QString();
   }
 
-  QString tmpStr;
-  if ( !journal->summary().isEmpty() ) {
-    tmpStr += eventViewerAddTag( "h2", journal->richSummary() );
-  }
+  QString tmpStr = eventViewerFormatHeader( journal );
+
   tmpStr += eventViewerAddTag(
-    "h3", i18n( "Journal for %1", journal->dtStartDateStr( false, spec ) ) );
+    "h3", i18n( "Journal for %1", IncidenceFormatter::dateToString( journal->dtStart(), false,
+                                                                    spec ) ) );
   if ( !journal->description().isEmpty() ) {
     tmpStr += eventViewerAddTag( "p", journal->richDescription() );
   }
@@ -603,10 +626,12 @@ QString IncidenceFormatter::extensiveDisplayStr( IncidenceBase *incidence, KDate
  *  Helper functions for the body part formatter of kmail
  *******************************************************************/
 
+//TODO: 4.4: remove "meeting" from the invitation strings
+
 //@cond PRIVATE
 static QString string2HTML( const QString &str )
 {
-  return Qt::convertFromPlainText( str, Qt::WhiteSpaceNormal );
+  return Qt::escape( str );
 }
 
 static QString cleanHtml( const QString &html )
@@ -623,9 +648,14 @@ static QString eventStartTimeStr( Event *event )
   QString tmp;
   if ( !event->allDay() ) {
     tmp =  i18nc( "%1: Start Date, %2: Start Time", "%1 %2",
-                  event->dtStartDateStr(), event->dtStartTimeStr() );
+                  IncidenceFormatter::dateToString( event->dtStart(), true,
+                                                    KSystemTimeZones::local() ),
+                  IncidenceFormatter::timeToString( event->dtStart(), true,
+                                                    KSystemTimeZones::local() ) );
   } else {
-    tmp = i18nc( "%1: Start Date", "%1 (all day)", event->dtStartDateStr() );
+    tmp = i18nc( "%1: Start Date", "%1 (all day)",
+                 IncidenceFormatter::dateToString( event->dtStart(), true,
+                                                   KSystemTimeZones::local() ) );
   }
   return tmp;
 }
@@ -636,9 +666,14 @@ static QString eventEndTimeStr( Event *event )
   if ( event->hasEndDate() && event->dtEnd().isValid() ) {
     if ( !event->allDay() ) {
       tmp =  i18nc( "%1: End Date, %2: End Time", "%1 %2",
-                    event->dtEndDateStr(), event->dtEndTimeStr() );
+                    IncidenceFormatter::dateToString( event->dtEnd(), true,
+                                                      KSystemTimeZones::local() ),
+                    IncidenceFormatter::timeToString( event->dtEnd(), true,
+                                                      KSystemTimeZones::local() ) );
     } else {
-      tmp = i18nc( "%1: End Date", "%1 (all day)", event->dtEndDateStr() );
+      tmp = i18nc( "%1: End Date", "%1 (all day)",
+                   IncidenceFormatter::dateToString( event->dtEnd(), true,
+                                                     KSystemTimeZones::local() ) );
     }
   } else {
     tmp = i18n( "Unspecified" );
@@ -653,28 +688,75 @@ static QString invitationRow( const QString &cell1, const QString &cell2 )
 
 static QString invitationsDetailsIncidence( Incidence *incidence, bool noHtmlMode )
 {
+  // if description and comment -> use both
+  // if description, but no comment -> use the desc as the comment (and no desc)
+  // if comment, but no description -> use the comment and no description
+
   QString html;
   QString descr;
-  if ( !incidence->descriptionIsRich() ) {
-    descr = string2HTML( incidence->description() );
+  QStringList comments;
+
+  if ( incidence->comments().isEmpty() ) {
+    if ( !incidence->description().isEmpty() ) {
+      // use description as comments
+      if ( !incidence->descriptionIsRich() ) {
+        comments << string2HTML( incidence->description() );
+      } else {
+        comments << incidence->richDescription();
+        if ( noHtmlMode ) {
+          comments[0] = cleanHtml( comments[0] );
+        }
+      }
+    }
+    //else desc and comments are empty
   } else {
-    descr = incidence->richDescription();
-    if ( noHtmlMode ) {
-      descr = cleanHtml( descr );
+    // non-empty comments
+    foreach ( const QString &c, incidence->comments() ) {
+      if ( !c.isEmpty() ) {
+        comments += string2HTML( c );
+      }
+    }
+    if ( !incidence->description().isEmpty() ) {
+      // use description too
+      if ( !incidence->descriptionIsRich() ) {
+        descr = string2HTML( incidence->description() );
+      } else {
+        descr = incidence->richDescription();
+        if ( noHtmlMode ) {
+          descr = cleanHtml( descr );
+        }
+      }
     }
-    descr = eventViewerAddTag( "p", descr );
   }
+
   if( !descr.isEmpty() ) {
-    html += "<br/><u>" + i18n( "Description:" ) + "</u><table border=\"0\"><tr><td>&nbsp;</td><td>";
-    html += descr + "</td></tr></table>";
+    html += "<p>";
+    html += "<table border=\"0\" style=\"margin-top:4px;\">";
+    html += "<tr><td><center>" +
+            eventViewerAddTag( "u", i18n( "Description:" ) ) +
+            "</center></td></tr>";
+    html += "<tr><td>" + descr + "</td></tr>";
+    html += "</table>";
   }
-  QStringList comments = incidence->comments();
+
   if ( !comments.isEmpty() ) {
-    html += "<br><u>" + i18n( "Comments:" ) + "</u><table border=\"0\"><tr><td>&nbsp;</td><td><ul>";
-    for ( int i = 0; i < comments.count(); ++i ) {
-      html += "<li>" + string2HTML( comments[i] ) + "</li>";
+    html += "<p>";
+    html += "<table border=\"0\" style=\"margin-top:4px;\">";
+    html += "<tr><td><center>" +
+            eventViewerAddTag( "u", i18n( "Comments:" ) ) +
+            "</center></td></tr>";
+    html += "<tr>";
+    if ( comments.count() > 1 ) {
+      html += "<td><ul>";
+      for ( int i=0; i < comments.count(); ++i ) {
+        html += "<li>" + comments[i] + "</li>";
+      }
+      html += "</ul></td>";
+    } else {
+      html += "<td>" + comments[0] + "</td>";
     }
-    html += "</ul></td></tr></table>";
+    html += "</tr>";
+    html += "</table>";
   }
   return html;
 }
@@ -686,11 +768,8 @@ static QString invitationDetailsEvent( Event *event, bool noHtmlMode )
     return QString();
   }
 
-  QString html;
-  QString tmp;
-
   QString sSummary = i18n( "Summary unspecified" );
-  if ( ! event->summary().isEmpty() ) {
+  if ( !event->summary().isEmpty() ) {
     if ( !event->summaryIsRich() ) {
       sSummary = string2HTML( event->summary() );
     } else {
@@ -698,12 +777,11 @@ static QString invitationDetailsEvent( Event *event, bool noHtmlMode )
       if ( noHtmlMode ) {
         sSummary = cleanHtml( sSummary );
       }
-      sSummary = eventViewerAddTag( "p", sSummary );
     }
   }
 
   QString sLocation = i18n( "Location unspecified" );
-  if ( ! event->location().isEmpty() ) {
+  if ( !event->location().isEmpty() ) {
     if ( !event->locationIsRich() ) {
       sLocation = string2HTML( event->location() );
     } else {
@@ -711,13 +789,11 @@ static QString invitationDetailsEvent( Event *event, bool noHtmlMode )
       if ( noHtmlMode ) {
         sLocation = cleanHtml( sLocation );
       }
-      sLocation = eventViewerAddTag( "p", sLocation );
     }
   }
 
   QString dir = ( QApplication::isRightToLeft() ? "rtl" : "ltr" );
-  html = QString( "<div dir=\"%1\">\n" ).arg( dir );
-  html += "<table border=\"0\" cellpadding=\"1\" cellspacing=\"1\">\n";
+  QString html = QString( "<div dir=\"%1\">\n" ).arg( dir );
 
   // Meeting summary & location rows
   html += invitationRow( i18n( "What:" ), sSummary );
@@ -731,7 +807,7 @@ static QString invitationDetailsEvent( Event *event, bool noHtmlMode )
 
   // Meeting Duration Row
   if ( !event->allDay() && event->hasEndDate() && event->dtEnd().isValid() ) {
-    tmp.clear();
+    QString tmp;
     QTime sDuration( 0, 0, 0 ), t;
     int secs = event->dtStart().secsTo( event->dtEnd() );
     t = sDuration.addSecs( secs );
@@ -749,9 +825,8 @@ static QString invitationDetailsEvent( Event *event, bool noHtmlMode )
     html += invitationRow( i18n( "Recurrence:" ), IncidenceFormatter::recurrenceString( event ) );
   }
 
-  html += "</table>\n";
+  html += "</div>";
   html += invitationsDetailsIncidence( event, noHtmlMode );
-  html += "</div>\n";
 
   return html;
 }
@@ -777,7 +852,8 @@ static QString invitationDetailsTodo( Todo *todo, bool noHtmlMode )
       sDescr = cleanHtml( sDescr );
     }
   }
-  QString html( "<table border=\"0\" cellpadding=\"1\" cellspacing=\"1\">\n" );
+  QString html = "<table border=\"0\" width=\"80%\" align=\"center\" "
+                 "cellpadding=\"1\" cellspacing=\"1\">";
   html += invitationRow( i18n( "Summary:" ), sSummary );
   html += invitationRow( i18n( "Description:" ), sDescr );
   html += "</table>\n";
@@ -806,10 +882,12 @@ static QString invitationDetailsJournal( Journal *journal, bool noHtmlMode )
       sDescr = cleanHtml( sDescr );
     }
   }
-  QString html( "<table border=\"0\" cellpadding=\"1\" cellspacing=\"1\">\n" );
+  QString html = "<table border=\"0\" width=\"80%\" align=\"center\" "
+                 "cellpadding=\"1\" cellspacing=\"1\">";
   html += invitationRow( i18n( "Summary:" ), sSummary );
   html += invitationRow( i18n( "Date:" ),
-                         journal->dtStartDateStr( false, journal->dtStart().timeSpec() ) );
+                         IncidenceFormatter::dateToString( journal->dtStart(), false,
+                                                           journal->dtStart().timeSpec() ) );
   html += invitationRow( i18n( "Description:" ), sDescr );
   html += "</table>\n";
   html += invitationsDetailsIncidence( journal, noHtmlMode );
@@ -823,10 +901,13 @@ static QString invitationDetailsFreeBusy( FreeBusy *fb )
     return QString();
   }
 
-  QString html( "<table border=\"0\" cellpadding=\"1\" cellspacing=\"1\">\n" );
+  QString html = "<table border=\"0\" width=\"80%\" align=\"center\" "
+                 "cellpadding=\"1\" cellspacing=\"1\">";
   html += invitationRow( i18n( "Person:" ), fb->organizer().fullName() );
   html += invitationRow( i18n( "Start date:" ),
-                         fb->dtStartDateStr( true, fb->dtStart().timeSpec() ) );
+                         IncidenceFormatter::dateToString( fb->dtStart(),
+                                                           true,
+                                                           fb->dtStart().timeSpec() ) );
   html += invitationRow( i18n( "End date:" ),
                          KGlobal::locale()->formatDate( fb->dtEnd().date(), KLocale::ShortDate ) );
   html += "<tr><td colspan=2><hr></td></tr>\n";
@@ -888,6 +969,7 @@ static QString invitationHeaderEvent( Event *event, ScheduleMessage *msg )
     return i18n( "This event has been published" );
   case iTIPRequest:
     if ( event->revision() > 0 ) {
+      //TODO: 4.4, remove the h3 tag
       return i18n( "<h3>This meeting has been updated</h3>" );
     } else {
       return i18n( "You have been invited to this meeting" );
@@ -1416,21 +1498,15 @@ static QString formatICalInvitationHelper( QString invitation, Calendar *mCalend
 
   // First make the text of the message
   QString html;
+  html += "<div align=\"center\" style=\"border:solid 1px; width:80%;\">";
+  html += "<table cellspacing=\"4\" style=\"border-width:4px; border-style:groove\">";
 
-  QString tableStyle = QString::fromLatin1(
-    "style=\"border: solid 1px; margin: 0em;\"" );
-  QString tableHead = QString::fromLatin1(
-    "<div align=\"center\">"
-    "<table width=\"80%\" cellpadding=\"1\" cellspacing=\"0\" %1>"
-    "<tr><td>" ).arg( tableStyle );
-
-  html += tableHead;
   IncidenceFormatter::InvitationHeaderVisitor headerVisitor;
   // The InvitationHeaderVisitor returns false if the incidence is somehow invalid, or not handled
   if ( !headerVisitor.act( incBase, msg ) ) {
     return QString();
   }
-  html += "<h3>" + headerVisitor.result() + "</h3>";
+  html += "<tr>" + eventViewerAddTag( "h3", headerVisitor.result() ) + "</tr>";
 
   IncidenceFormatter::InvitationBodyVisitor bodyVisitor( noHtmlMode );
   if ( !bodyVisitor.act( incBase, msg ) ) {
@@ -1447,17 +1523,15 @@ static QString formatICalInvitationHelper( QString invitation, Calendar *mCalend
     }
   }
 
-  html += "<br/>";
-  html += "<table border=\"0\" cellspacing=\"0\"><tr><td>&nbsp;</td></tr><tr>";
-
-#if 0
-  // TODO: implement this
-  html += helper->makeLinkURL( "accept", i18n( "[Enter this into my calendar]" ) );
-  html += "</td><td> &nbsp; </td><td>";
-#endif
-
   // Add groupware links
 
+  html += "<p>";
+  html += "<table border=\"0\" align=\"center\" cellspacing=\"4\"><tr>";
+
+  //TODO: 4.4, in tdOpen, change border-width:0px to border-width:2px and also
+  //remove the [] on the button strings: "Accept", "Decline", "Counter", etc.
+  const QString tdOpen = "<td style=\"border-width:0px;border-style:outset\">";
+  const QString tdClose = "</td>";
   Incidence *incidence = dynamic_cast<Incidence*>( incBase );
   switch ( msg->method() ) {
   case iTIPPublish:
@@ -1466,40 +1540,61 @@ static QString formatICalInvitationHelper( QString invitation, Calendar *mCalend
   case iTIPAdd:
   {
     if ( incidence && incidence->revision() > 0 && ( existingIncidence || !helper->calendar() ) ) {
+      html += tdOpen;
       if ( incBase->type() == "Todo" ) {
-        html += "<td colspan=\"11\">";
+        //TODO: 4.4, remove the []
         html += helper->makeLink( "reply", i18n( "[Enter this into my to-do list]" ) );
       } else {
-        html += "<td colspan=\"13\">";
         html += helper->makeLink( "reply", i18n( "[Enter this into my calendar]" ) );
       }
-      html += "</td></tr><tr>";
+      html += tdClose;
     }
-    html += "<td>";
+
     if ( incidence && !existingIncidence ) {
       // Accept
+      html += tdOpen;
+        //TODO: 4.4, remove the []
       html += helper->makeLink( "accept", i18nc( "accept to-do request", "[Accept]" ) );
-      html += "</td><td> &nbsp; </td><td>";
+      html += tdClose;
+
+      // Accept conditionally
+      html += tdOpen;
+      //TODO: 4.4, remove the []
       html += helper->makeLink( "accept_conditionally",
-                              i18nc( "Accept conditionally", "[Accept cond.]" ) );
-      html += "</td><td> &nbsp; </td><td>";
-      // counter proposal
+                                i18nc( "Accept conditionally", "[Accept cond.]" ) );
+      html += tdClose;
+
+      // Counter proposal
+      html += tdOpen;
+      //TODO: 4.4, remove the []
       html += helper->makeLink( "counter", i18n( "[Counter proposal]" ) );
-      html += "</td><td> &nbsp; </td><td>";
+      html += tdClose;
+
       // Decline
+      html += tdOpen;
+      //TODO: 4.4, remove the []
       html += helper->makeLink( "decline", i18nc( "decline to-do request", "[Decline]" ) );
-      html += "</td><td> &nbsp; </td><td>";
+      html += tdClose;
 
       // Delegate
+      html += tdOpen;
+      //TODO: 4.4, remove the []
       html += helper->makeLink( "delegate", i18nc( "delegate to-do to another", "[Delegate]" ) );
-      html += "</td><td> &nbsp; </td><td>";
+      html += tdClose;
 
       // Forward
+      html += tdOpen;
+      //TODO: 4.4, remove the []
       html += helper->makeLink( "forward", i18nc( "forward request to another", "[Forward]" ) );
+      html += tdClose;
 
+      // Check in calendar
       if ( incBase->type() == "Event" ) {
-        html += "</b></a></td><td> &nbsp; </td><td>";
+        html += tdOpen;
+        //TODO: 4.4, remove the []
+        //TODO: 4.4, change to "Check calendar"
         html += helper->makeLink( "check_calendar", i18n("[Check my calendar]" ) );
+        html += tdClose;
       }
     }
     break;
@@ -1507,24 +1602,41 @@ static QString formatICalInvitationHelper( QString invitation, Calendar *mCalend
 
   case iTIPCancel:
     // Cancel event from my calendar
+    html += tdOpen;
+    //TODO: 4.4, remove the []
     html += helper->makeLink( "cancel", i18n( "[Remove this from my calendar]" ) );
+    html += tdClose;
     break;
 
   case iTIPReply:
     // Enter this into my calendar
+    html += tdOpen;
+    //TODO: 4.4, remove the []
+    //TODO: 4.4, change string to "Enter this response into my..."
     if ( incBase->type() == "Todo" ) {
       html += helper->makeLink( "reply", i18n( "[Enter this into my to-do list]" ) );
     } else {
       html += helper->makeLink( "reply", i18n( "[Enter this into my calendar]" ) );
     }
+    html += tdClose;
     break;
 
   case iTIPCounter:
+    html += tdOpen;
+    //TODO: 4.4, remove the []
     html += helper->makeLink( "accept_counter", i18n( "[Accept]" ) );
-    html += "&nbsp;";
+    html += tdClose;
+
+    html += tdOpen;
+    //TODO: 4.4, remove the []
     html += helper->makeLink( "decline_counter", i18n( "[Decline]" ) );
-    html += "&nbsp;";
+    html += tdClose;
+
+    html += tdOpen;
+    //TODO: 4.4, remove the []
+    //TODO: 4.4, change string to "Check calendar"
     html += helper->makeLink( "check_calendar", i18n( "[Check my calendar]" ) );
+    html += tdClose;
     break;
 
   case iTIPDeclineCounter:
@@ -1532,10 +1644,12 @@ static QString formatICalInvitationHelper( QString invitation, Calendar *mCalend
     break;
   }
 
-  html += "</td></tr></table>";
-
-  html += "</td></tr></table><br></div>";
+  // close the groupware table
+  html += "</tr></table>";
 
+  // close the top-level table
+  html += "</table></div>";
+  kDebug() << html;
   return html;
 }
 //@endcond
@@ -1599,19 +1713,19 @@ QString IncidenceFormatter::ToolTipVisitor::dateRangeText( Event *event )
   QString tmp;
   if ( event->isMultiDay() ) {
 
-    tmp = event->dtStartStr( true, mSpec );
+    tmp = IncidenceFormatter::dateToString( event->dtStart(), true, mSpec );
     ret += "<br>" + i18nc( "Event start", "<i>From:</i> %1", tmp );
 
-    tmp = event->dtEndStr( true, mSpec );
+    tmp = IncidenceFormatter::dateToString( event->dtEnd(), true, mSpec );
     ret += "<br>" + i18nc( "Event end","<i>To:</i> %1", tmp );
 
   } else {
 
     ret += "<br>" +
-           i18n( "<i>Date:</i> %1", event->dtStartDateStr( true, mSpec ) );
+      i18n( "<i>Date:</i> %1", IncidenceFormatter::dateToString( event->dtStart(), true, mSpec ) );
     if ( !event->allDay() ) {
-      const QString dtStartTime = event->dtStartTimeStr( true, mSpec );
-      const QString dtEndTime = event->dtEndTimeStr( true, mSpec );
+      const QString dtStartTime = IncidenceFormatter::timeToString( event->dtStart(), true, mSpec );
+      const QString dtEndTime = IncidenceFormatter::timeToString( event->dtEnd(), true, mSpec );
       if ( dtStartTime == dtEndTime ) {
         // to prevent 'Time: 17:00 - 17:00'
         tmp = "<br>" +
@@ -1637,10 +1751,14 @@ QString IncidenceFormatter::ToolTipVisitor::dateRangeText( Todo *todo )
     // No need to add <i> here. This is separated issue and each line
     // is very visible on its own. On the other hand... Yes, I like it
     // italics here :)
-    ret += "<br>" + i18n( "<i>Start:</i> %1", todo->dtStartStr( true, false, mSpec ) );
+    ret += "<br>" + i18n( "<i>Start:</i> %1",
+                          IncidenceFormatter::dateToString( todo->dtStart( false ), true, mSpec ) );
   }
   if ( todo->hasDueDate() && todo->dtDue().isValid() ) {
-    ret += "<br>" + i18n( "<i>Due:</i> %1", todo->dtDueStr( true, mSpec ) );
+    ret += "<br>" + i18n( "<i>Due:</i> %1",
+                          IncidenceFormatter::dateTimeToString( todo->dtDue(),
+                                                                todo->allDay(),
+                                                                true, mSpec ) );
   }
   if ( todo->isCompleted() ) {
     ret += "<br>" +
@@ -1659,7 +1777,8 @@ QString IncidenceFormatter::ToolTipVisitor::dateRangeText( Journal *journal )
   QString ret;
   if ( journal->dtStart().isValid() ) {
     ret += "<br>" +
-           i18n( "<i>Date:</i> %1", journal->dtStartDateStr( false, mSpec ) );
+           i18n( "<i>Date:</i> %1",
+                 IncidenceFormatter::dateToString( journal->dtStart(), false, mSpec ) );
   }
   return ret.replace( ' ', "&nbsp;" );
 }
@@ -1826,15 +1945,19 @@ bool IncidenceFormatter::MailBodyVisitor::visit( Event *event )
   };
 
   mResult = mailBodyIncidence( event );
-  mResult += i18n( "Start Date: %1\n", event->dtStartDateStr( true, mSpec ) );
+  mResult += i18n( "Start Date: %1\n", IncidenceFormatter::dateToString( event->dtStart(), true,
+                                                                         mSpec ) );
   if ( !event->allDay() ) {
-    mResult += i18n( "Start Time: %1\n", event->dtStartTimeStr( true, mSpec ) );
+    mResult += i18n( "Start Time: %1\n", IncidenceFormatter::timeToString( event->dtStart(),
+                                                                           true, mSpec ) );
   }
   if ( event->dtStart() != event->dtEnd() ) {
-    mResult += i18n( "End Date: %1\n", event->dtEndDateStr( true, mSpec ) );
+    mResult += i18n( "End Date: %1\n", IncidenceFormatter::dateToString( event->dtEnd(), true,
+                                                                         mSpec ) );
   }
   if ( !event->allDay() ) {
-    mResult += i18n( "End Time: %1\n", event->dtEndTimeStr( true, mSpec ) );
+    mResult += i18n( "End Time: %1\n", IncidenceFormatter::timeToString( event->dtEnd(), true,
+                                                                         mSpec ) );
   }
   if ( event->recurs() ) {
     Recurrence *recur = event->recurrence();
@@ -1873,15 +1996,19 @@ bool IncidenceFormatter::MailBodyVisitor::visit( Todo *todo )
   mResult = mailBodyIncidence( todo );
 
   if ( todo->hasStartDate() && todo->dtStart().isValid() ) {
-    mResult += i18n( "Start Date: %1\n", todo->dtStartDateStr( true, false, mSpec ) );
+    mResult += i18n( "Start Date: %1\n",
+                     IncidenceFormatter::dateToString( todo->dtStart(false), true, mSpec ) );
     if ( !todo->allDay() ) {
-      mResult += i18n( "Start Time: %1\n", todo->dtStartTimeStr( true, false, mSpec ) );
+      mResult += i18n( "Start Time: %1\n",
+                       IncidenceFormatter::timeToString( todo->dtStart(false), true, mSpec ) );
     }
   }
   if ( todo->hasDueDate() && todo->dtDue().isValid() ) {
-    mResult += i18n( "Due Date: %1\n", todo->dtDueDateStr( true, mSpec ) );
+    mResult += i18n( "Due Date: %1\n",
+                     IncidenceFormatter::dateToString( todo->dtDue(), true, mSpec ) );
     if ( !todo->allDay() ) {
-      mResult += i18n( "Due Time: %1\n", todo->dtDueTimeStr( true, mSpec ) );
+      mResult += i18n( "Due Time: %1\n",
+                       IncidenceFormatter::timeToString( todo->dtDue(), true, mSpec ) );
     }
   }
   QString details = todo->richDescription();
@@ -1894,9 +2021,13 @@ bool IncidenceFormatter::MailBodyVisitor::visit( Todo *todo )
 bool IncidenceFormatter::MailBodyVisitor::visit( Journal *journal )
 {
   mResult = mailBodyIncidence( journal );
-  mResult += i18n( "Date: %1\n", journal->dtStartDateStr( true, mSpec ) );
+  mResult += i18n( "Date: %1\n", IncidenceFormatter::dateToString( journal->dtStart(), true,
+                                                                mSpec ) );
+
   if ( !journal->allDay() ) {
-    mResult += i18n( "Time: %1\n", journal->dtStartTimeStr( true, mSpec ) );
+    mResult += i18n( "Time: %1\n",
+                     IncidenceFormatter::timeToString( journal->dtStart(), true, mSpec ) );
+
   }
   if ( !journal->description().isEmpty() ) {
     mResult += i18n( "Text of the journal:\n%1\n", journal->richDescription() );
@@ -2233,3 +2364,67 @@ QString IncidenceFormatter::recurrenceString( Incidence *incidence )
     return i18n( "Incidence recurs" );
   }
 }
+
+QString IncidenceFormatter::timeToString( const KDateTime &date,
+                                          bool shortfmt,
+                                          const KDateTime::Spec &spec )
+{
+  if ( spec.isValid() ) {
+
+    QString timeZone;
+    if ( spec.timeZone() != KSystemTimeZones::local() ) {
+      timeZone = ' ' + spec.timeZone().name();
+    }
+
+    return KGlobal::locale()->formatTime( date.toTimeSpec( spec ).time(), !shortfmt ) + timeZone;
+  } else {
+    return KGlobal::locale()->formatTime( date.time(), !shortfmt );
+  }
+}
+
+QString IncidenceFormatter::dateToString( const KDateTime &date,
+                                          bool shortfmt,
+                                          const KDateTime::Spec &spec )
+{
+  if ( spec.isValid() ) {
+
+    QString timeZone;
+    if ( spec.timeZone() != KSystemTimeZones::local() ) {
+      timeZone = ' ' + spec.timeZone().name();
+    }
+
+    return
+      KGlobal::locale()->formatDate( date.toTimeSpec( spec ).date(),
+                                     ( shortfmt ? KLocale::ShortDate : KLocale::LongDate ) ) +
+      timeZone;
+  } else {
+    return
+      KGlobal::locale()->formatDate( date.date(),
+                                     ( shortfmt ? KLocale::ShortDate : KLocale::LongDate ) );
+  }
+}
+
+QString IncidenceFormatter::dateTimeToString( const KDateTime &date,
+                                              bool allDay,
+                                              bool shortfmt,
+                                              const KDateTime::Spec &spec )
+{
+  if ( allDay ) {
+    return dateToString( date, shortfmt, spec );
+  }
+
+  if ( spec.isValid() ) {
+    QString timeZone;
+    if ( spec.timeZone() != KSystemTimeZones::local() ) {
+      timeZone = ' ' + spec.timeZone().name();
+    }
+
+    return KGlobal::locale()->formatDateTime(
+      date.toTimeSpec( spec ).dateTime(),
+      ( shortfmt ? KLocale::ShortDate : KLocale::LongDate ) ) + timeZone;
+  } else {
+    return  KGlobal::locale()->formatDateTime(
+      date.dateTime(),
+      ( shortfmt ? KLocale::ShortDate : KLocale::LongDate ) );
+  }
+}
