@@ -1,7 +1,7 @@
 /* This file is part of KDE
    Copyright (C) 2000 by Wolfram Diestel <wolfram@steloj.de>
    Copyright (C) 2005 by Tim Way <tim@way.hrcoxmail.com>
-   Copyright (C) 2005 by Volker Krause <volker.krause@rwth-aachen.de>
+   Copyright (C) 2005 by Volker Krause <vkrause@kde.org>
 
    This is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,8 +23,7 @@
 #include <kglobal.h>
 #include <klocale.h>
 
-#define NNTP_PORT 119
-#define NNTPS_PORT 563
+#include <kio/ioslave_defaults.h>
 
 #define DBG_AREA 7114
 #define DBG kDebug(DBG_AREA)
@@ -66,7 +65,7 @@ NNTPProtocol::NNTPProtocol ( const QByteArray & pool, const QByteArray & app, bo
   DBG << "=============> NNTPProtocol::NNTPProtocol";
 
   readBufferLen = 0;
-  m_defaultPort = isSSL ? NNTPS_PORT : NNTP_PORT;
+  m_defaultPort = isSSL ? DEFAULT_NNTPS_PORT : DEFAULT_NNTP_PORT;
   m_port = m_defaultPort;
 }
 
