@@ -45,6 +45,16 @@ namespace KMime {
 
 namespace Types {
 
+// QUrl::fromAce is extremely expensive, so only use it when necessary.
+// Fortunately, the presence of IDNA is readily detected with a substring match...
+static inline QString QUrl_fromAce_wrapper( const QString & domain )
+{
+    if ( domain.contains( QLatin1String( "xn--" ) ) )
+        return QUrl::fromAce( domain.toLatin1() );
+    else
+        return domain;
+}
+
 static QString addr_spec_as_string( const AddrSpec & as, bool pretty )
 {
   if ( as.isEmpty() ) {
@@ -66,7 +76,7 @@ static QString addr_spec_as_string( const AddrSpec & as, bool pretty )
       result += ch;
     }
   }
-  const QString dom = pretty ? QUrl::fromAce( as.domain.toLatin1() ) : as.domain ;
+  const QString dom = pretty ? QUrl_fromAce_wrapper( as.domain ) : as.domain ;
   if ( needsQuotes ) {
     return '"' + result + "\"@" + dom;
   } else {
@@ -207,7 +217,7 @@ bool parseEncodedWord( const char* &scursor, const char * const send,
   char ch = *scursor++;
 
   if ( ch != '?' ) {
-    kDebug(5320) << "first";
+    // kDebug(5320) << "first";
     KMIME_WARN_PREMATURE_END_OF( EncodedWord );
     return false;
   }
@@ -229,7 +239,7 @@ bool parseEncodedWord( const char* &scursor, const char * const send,
 
   // not found? can't be an encoded-word!
   if ( scursor == send || *scursor != '?' ) {
-    kDebug(5320) << "second";
+    // kDebug(5320) << "second";
     KMIME_WARN_PREMATURE_END_OF( EncodedWord );
     return false;
   }
@@ -260,7 +270,7 @@ bool parseEncodedWord( const char* &scursor, const char * const send,
 
   // not found? Can't be an encoded-word!
   if ( scursor == send || *scursor != '?' ) {
-    kDebug(5320) << "third";
+    // kDebug(5320) << "third";
     KMIME_WARN_PREMATURE_END_OF( EncodedWord );
     return false;
   }
@@ -268,9 +278,9 @@ bool parseEncodedWord( const char* &scursor, const char * const send,
   // extract the encoding information:
   QByteArray maybeEncoding( encodingStart, scursor - encodingStart );
 
-  kDebug(5320) << "parseEncodedWord: found charset == \"" << maybeCharset
-           << "\"; language == \"" << maybeLanguage
-           << "\"; encoding == \"" << maybeEncoding << "\"";
+  // kDebug(5320) << "parseEncodedWord: found charset == \"" << maybeCharset
+  //         << "\"; language == \"" << maybeLanguage
+  //         << "\"; encoding == \"" << maybeEncoding << "\"";
 
   //
   // STEP 3:
@@ -291,14 +301,14 @@ bool parseEncodedWord( const char* &scursor, const char * const send,
   // not found? Can't be an encoded-word!
   // ### maybe evaluate it nonetheless if the rest is OK?
   if ( scursor == send || *scursor != '?' ) {
-    kDebug(5320) << "fourth";
+    // kDebug(5320) << "fourth";
     KMIME_WARN_PREMATURE_END_OF( EncodedWord );
     return false;
   }
   scursor++;
   // check for trailing '=':
   if ( scursor == send || *scursor != '=' ) {
-    kDebug(5320) << "fifth";
+    // kDebug(5320) << "fifth";
     KMIME_WARN_PREMATURE_END_OF( EncodedWord );
     return false;
   }
@@ -345,7 +355,7 @@ bool parseEncodedWord( const char* &scursor, const char * const send,
     return false;
   };
 
-  kDebug(5320) << "mimeName(): \"" << textCodec->name() << "\"";
+  // kDebug(5320) << "mimeName(): \"" << textCodec->name() << "\"";
 
   // allocate a temporary buffer to store the 8bit text:
   int encodedTextLength = encodedTextEnd - encodedTextStart;
@@ -366,7 +376,7 @@ bool parseEncodedWord( const char* &scursor, const char * const send,
 
   result = textCodec->toUnicode( buffer.begin(), bit - buffer.begin() );
 
-  kDebug(5320) << "result now: \"" << result << "\"";
+  // kDebug(5320) << "result now: \"" << result << "\"";
   // cleanup:
   delete dec;
   language = maybeLanguage;
@@ -1538,7 +1548,7 @@ static void decodeRFC2231Value( Codec* &rfc2231Codec,
 
   value += textcodec->toUnicode( buffer.begin(), bit - buffer.begin() );
 
-  kDebug(5320) << "value now: \"" << value << "\"";
+  // kDebug(5320) << "value now: \"" << value << "\"";
   // cleanup:
   delete dec;
 }
@@ -1655,7 +1665,7 @@ bool parseParameterList( const char* &scursor, const char * const send,
   return true;
 }
 
-static const char * stdDayNames[] = {
+static const char * const stdDayNames[] = {
   "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"
 };
 static const int stdDayNamesLen = sizeof stdDayNames / sizeof *stdDayNames;
@@ -1678,7 +1688,7 @@ static bool parseDayName( const char* &scursor, const char * const send )
   return false;
 }
 
-static const char * stdMonthNames[] = {
+static const char * const stdMonthNames[] = {
   "Jan", "Feb", "Mar", "Apr", "May", "Jun",
   "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"
 };
