@@ -78,7 +78,6 @@ QStringList KPIMUtils::splitAddressList( const QString &aStr )
         if ( commentlevel > 0 ) {
           commentlevel--;
         } else {
-          kDebug() << "Error in address splitting: Unmatched ')'";
           return list;
         }
       }
@@ -87,6 +86,7 @@ QStringList KPIMUtils::splitAddressList( const QString &aStr )
       index++; // ignore the quoted character
       break;
     case ',' :
+    case ';' :
       if ( !insidequote && ( commentlevel == 0 ) ) {
         addr = aStr.mid( addrstart, index - addrstart );
         if ( !addr.isEmpty() ) {
@@ -103,8 +103,6 @@ QStringList KPIMUtils::splitAddressList( const QString &aStr )
     if ( !addr.isEmpty() ) {
       list += addr.simplified();
     }
-  } else {
-    kDebug() << "Error in address splitting: Unexpected end of address list";
   }
 
   return list;
@@ -119,7 +117,6 @@ KPIMUtils::EmailParseResult splitAddressInternal( const QByteArray  address,
                                                   bool allowMultipleAddresses )
 {
   //  kDebug() << "address";
-
   displayName = "";
   addrSpec = "";
   comment = "";
@@ -509,7 +506,7 @@ KPIMUtils::EmailParseResult KPIMUtils::isValidAddressList( const QString &aStr,
     return AddressEmpty;
   }
 
-  QStringList list = splitAddressList( aStr );
+  const QStringList list = splitAddressList( aStr );
 
   QStringList::const_iterator it = list.begin();
   EmailParseResult errorCode = AddressOk;
@@ -552,17 +549,17 @@ QString KPIMUtils::emailParseResultToString( EmailParseResult errorCode )
     return i18n( "The email address you entered is valid." );
   case UnclosedAngleAddr :
     return i18n( "The email address you entered is not valid because it "
-                 "contains an unclosed anglebracket." );
+                 "contains an unclosed angle bracket." );
   case UnopenedAngleAddr :
     return i18n( "The email address you entered is not valid because it "
-                 "contains an unopened anglebracket." );
+                 "contains too many closing angle brackets." );
   case UnexpectedComma :
     return i18n( "The email address you have entered is not valid because it "
                  "contains an unexpected comma." );
   case UnexpectedEnd :
     return i18n( "The email address you entered is not valid because it ended "
-                 "unexpectedly, this probably means you have used an escaping "
-                 "type character like an \\  as the last character in your "
+                 "unexpectedly. This probably means you have used an escaping "
+                 "type character like a '\\' as the last character in your "
                  "email address." );
   case UnbalancedQuote :
     return i18n( "The email address you entered is not valid because it "
@@ -576,7 +573,7 @@ QString KPIMUtils::emailParseResultToString( EmailParseResult errorCode )
                  "contains an illegal character." );
   case InvalidDisplayName :
     return i18n( "The email address you have entered is not valid because it "
-                 "contains an invalid displayname." );
+                 "contains an invalid display name." );
   }
   return i18n( "Unknown problem with email address" );
 }
@@ -646,9 +643,11 @@ QByteArray KPIMUtils::extractEmailAddress( const QByteArray &address )
                           false/* don't allow multiple addresses */ );
   if ( result != AddressOk ) {
     addrSpec = QByteArray();
-    kDebug() // << "\n"
-      << "Input: aStr\nError:"
-      << emailParseResultToString( result );
+    if ( result != AddressEmpty ) {
+      kDebug()
+        << "Input: aStr\nError:"
+        << emailParseResultToString( result );
+    }
   }
 
   return addrSpec;
@@ -669,9 +668,11 @@ QByteArray KPIMUtils::firstEmailAddress( const QByteArray &addresses )
                           true/* allow multiple addresses */ );
   if ( result != AddressOk ) {
     addrSpec = QByteArray();
-    kDebug() // << "\n"
-      << "Input: aStr\nError:"
-      << emailParseResultToString( result );
+    if ( result != AddressEmpty ) {
+      kDebug()
+        << "Input: aStr\nError:"
+        << emailParseResultToString( result );
+    }
   }
 
   return addrSpec;
@@ -898,7 +899,7 @@ QString KPIMUtils::normalizedAddress( const QString &displayName,
   if ( displayName.isEmpty() && comment.isEmpty() ) {
     return addrSpec;
   } else if ( comment.isEmpty() ) {
-    if ( !displayName.startsWith('\"') ) {
+    if ( !displayName.startsWith( '\"' ) ) {
       return quoteNameIfNecessary( displayName ) + " <" + addrSpec + '>';
     } else {
       return displayName + " <" + addrSpec + '>';
@@ -970,8 +971,6 @@ QString KPIMUtils::normalizeAddressesAndDecodeIdn( const QString &str )
           << normalizedAddress( QString::fromUtf8( displayName ),
                                 fromIdn( QString::fromUtf8( addrSpec ) ),
                                 QString::fromUtf8( comment ) );
-      } else {
-        kDebug() << "splitting address failed:" << *it;
       }
     }
   }
@@ -1006,8 +1005,6 @@ QString KPIMUtils::normalizeAddressesAndEncodeIdn( const QString &str )
         normalizedAddressList << normalizedAddress( QString::fromUtf8( displayName ),
                                                     toIdn( QString::fromUtf8( addrSpec ) ),
                                                     QString::fromUtf8( comment ) );
-      } else {
-        kDebug() << "splitting address failed:" << *it;
       }
     }
   }
