@@ -215,10 +215,11 @@ class KRESOURCES_EXPORT Resource : public QObject
 class KRESOURCES_EXPORT PluginFactoryBase : public KPluginFactory
 {
   public:
-    explicit PluginFactoryBase(const char* componentName = 0, const char *catalogName = 0, QObject *parent = 0)
-      : KPluginFactory(componentName, catalogName, parent) {}
-    explicit PluginFactoryBase(const KAboutData &aboutData, QObject *parent = 0)
-      : KPluginFactory(aboutData, parent) {}
+    explicit PluginFactoryBase( const char *componentName=0,
+                                const char *catalogName=0, QObject *parent=0 )
+      : KPluginFactory( componentName, catalogName, parent ) {}
+    explicit PluginFactoryBase( const KAboutData &aboutData, QObject *parent = 0 )
+      : KPluginFactory( aboutData, parent ) {}
 
     virtual Resource *resource( const KConfigGroup &group ) = 0;
     virtual Resource *resource() = 0;
@@ -234,10 +235,11 @@ template<class TR,class TC>
 class PluginFactory : public PluginFactoryBase
 {
   public:
-    explicit PluginFactory(const char* componentName = 0, const char *catalogName = 0, QObject *parent = 0)
-      : PluginFactoryBase(componentName, catalogName, parent) {}
-    explicit PluginFactory(const KAboutData &aboutData, QObject *parent = 0)
-      : PluginFactoryBase(aboutData, parent) {}
+    explicit PluginFactory( const char *componentName=0,
+                            const char *catalogName=0, QObject *parent=0 )
+      : PluginFactoryBase( componentName, catalogName, parent ) {}
+    explicit PluginFactory( const KAboutData &aboutData, QObject *parent = 0 )
+      : PluginFactoryBase( aboutData, parent ) {}
 
     virtual Resource *resource( const KConfigGroup &group )
     {
